@@ -40,14 +40,19 @@ class AsyncClient(client.Client):
                  packets. Custom json modules must have ``dumps`` and ``loads``
                  functions that are compatible with the standard library
                  versions.
+    :param handle_sigint: Set to ``True`` to automatically handle disconnection
+                          when the process is interrupted, or to ``False`` to
+                          leave interrupt handling to the calling application.
+                          Interrupt handling can only be enabled when the
+                          client instance is created in the main thread.
 
     The Engine.IO configuration supports the following settings:
 
     :param request_timeout: A timeout in seconds for requests. The default is
                             5 seconds.
-    :param http_session: an initialized ``requests.Session`` object to be used
-                         when sending requests to the server. Use it if you
-                         need to add special client options such as proxy
+    :param http_session: an initialized ``aiohttp.ClientSession`` object to be
+                         used when sending requests to the server. Use it if
+                         you need to add special client options such as proxy
                          servers, SSL certificates, etc.
     :param ssl_verify: ``True`` to verify SSL certificates, or ``False`` to
                        skip SSL certificate verification, allowing
@@ -249,6 +254,12 @@ class AsyncClient(client.Client):
     async def call(self, event, data=None, namespace=None, timeout=60):
         """Emit a custom event to a client and wait for the response.
 
+        This method issues an emit with a callback and waits for the callback
+        to be invoked before returning. If the callback isn't invoked before
+        the timeout, then a ``TimeoutError`` exception is raised. If the
+        Socket.IO connection drops during the wait, this method still waits
+        until the specified timeout.
+
         :param event: The event name. It can be any string. The event names
                       ``'connect'``, ``'message'`` and ``'disconnect'`` are
                       reserved and should not be used.
@@ -311,9 +322,7 @@ class AsyncClient(client.Client):
         :param args: arguments to pass to the function.
         :param kwargs: keyword arguments to pass to the function.
 
-        This function returns an object compatible with the `Thread` class in
-        the Python standard library. The `start()` method on this object is
-        already called by this function.
+        The return value is a ``asyncio.Task`` object.
         """
         return self.eio.start_background_task(target, *args, **kwargs)
 
@@ -422,7 +431,8 @@ class AsyncClient(client.Client):
             handler = None
             if event in self.handlers[namespace]:
                 handler = self.handlers[namespace][event]
-            elif '*' in self.handlers[namespace]:
+            elif event not in self.reserved_events and \
+                    '*' in self.handlers[namespace]:
                 handler = self.handlers[namespace]['*']
                 args = (event, *args)
             if handler:
@@ -487,7 +497,7 @@ class AsyncClient(client.Client):
         """Handle the Engine.IO connection event."""
         self.logger.info('Engine.IO connection established')
         self.sid = self.eio.sid
-        real_auth = await self._get_real_value(self.connection_auth)
+        real_auth = await self._get_real_value(self.connection_auth) or {}
         for n in self.connection_namespaces:
             await self._send_packet(self.packet_class(
                 packet.CONNECT, data=real_auth, namespace=n))
